(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2013-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of OCamlGen, 3.3+dev4 generated code *)

let print_component_number ppf = function
  | u_t -> Unatural_print.print_t ppf u_t
;;

let print_point ppf = function
  | (u_t, u_t0) ->
    Format.fprintf ppf "%,@[<1>(@,"; Unatural_print.print_t ppf u_t;
    Format.fprintf ppf "%,,@ "; Unatural_print.print_t ppf u_t0;
    Format.fprintf ppf "%,@,)@]"
;;

let print_parameter pp_a ppf = function
  | a_u_m -> Umatrix_structural_mapping_print.print_mapping pp_a ppf a_u_m

and print_sub_parameter pp_a ppf = function
  | a_u_s ->
    Umatrix_structural_mapping_print.print_sub_mapping pp_a ppf a_u_s
;;

let print_gradient pp_a ppf = function | a_p -> print_parameter pp_a ppf a_p
;;

let rec print_indicator pp_a ppf = function | a -> pp_a ppf a

and print_first_order_indicator pp_a ppf = function
  | a_i -> print_indicator pp_a ppf a_i

and print_exact_indicator pp_a ppf = function
  | a_i -> print_indicator pp_a ppf a_i
;;

let print_candidate_cutting pp_a ppf = function
  | {
      Refinement_types.cutting = u_d;
      Refinement_types.first_order_indicator = a_f;
    } ->
    Format.fprintf ppf "%,@[<1>{@,"; Format.fprintf ppf "%,@[<1>cutting =@ ";
    Umatrix_nonempty_set_print.print_dichotomy ppf u_d;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>first_order_indicator =@ ";
    print_first_order_indicator pp_a ppf a_f; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@,}@]"
;;

let print_zone pp_a ppf = function
  | a_a_c_l_u_b ->
    Umatrix_structural_mapping_print.print_block pp_a
     (Lib_print.print_List (print_candidate_cutting pp_a)) ppf a_a_c_l_u_b
;;

let print_zone_number ppf = function
  | u_b -> Umatrix_structural_mapping_print.print_block_number ppf u_b
;;

let print_bounds ppf = function
  | { Refinement_types.ll = p; Refinement_types.ur = p0; } ->
    Format.fprintf ppf "%,@[<1>{@,"; Format.fprintf ppf "%,@[<1>ll =@ ";
    print_point ppf p; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>ur =@ "; print_point ppf p0;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@,}@]"
;;

let print_zonation pp_a ppf = function
  | a_a_c_l_a_g_u_t ->
    Umatrix_structural_mapping_print.print_t pp_a
     (Lib_print.print_List (print_candidate_cutting pp_a))
     (print_gradient pp_a) ppf a_a_c_l_a_g_u_t
;;

let print_forced_zone pp_a ppf = function
  | a_s_a_c_l_u_a ->
    Udynamic_graph_print.print_arrow (print_sub_parameter pp_a)
     (Lib_print.print_List (print_candidate_cutting pp_a)) ppf a_s_a_c_l_u_a
;;

let print_forced_zonation pp_a ppf = function
  | a_f_a -> Lib_print.print_Array (print_forced_zone pp_a) ppf a_f_a
;;

let print_partition pp_a ppf = function
  | a_s_a -> Lib_print.print_Array (print_sub_parameter pp_a) ppf a_s_a
;;

let print_command_line ppf = function
  | s -> Lib_print.print_quoted_string ppf s
;;

let print_external_program_command ppf = function
  | c -> print_command_line ppf c
;;

let print_dimension ppf = function | u_t -> Unatural_print.print_t ppf u_t
;;

let print_dimension_management ppf = function
  | Refinement_types.Vector -> Format.fprintf ppf "%s" "Vector"
  | Refinement_types.Best_component_only ->
    Format.fprintf ppf "%s" "Best_component_only"
;;

let print_number_of_cuts ppf = function
  | u_t -> Unatural_print.print_t ppf u_t
;;

let print_basic_cutting_family ppf = function
  | Refinement_types.Horizontal_cut ->
    Format.fprintf ppf "%s" "Horizontal_cut"
  | Refinement_types.Vertical_cut -> Format.fprintf ppf "%s" "Vertical_cut"
;;

let print_cutting_strategy ppf = function
  | Refinement_types.Best_in_a_family (n, b_u_l) ->
    Format.fprintf ppf "@[<1>%s@ " "Best_in_a_family";
    Format.fprintf ppf "%,@[<1>(@,"; print_number_of_cuts ppf n;
    Format.fprintf ppf "%,,@ ";
    Ulist1_print.print_list1 print_basic_cutting_family ppf b_u_l;
    Format.fprintf ppf "%,@,)@]"; Format.fprintf ppf "%,@]"
  | Refinement_types.Overall_best -> Format.fprintf ppf "%s" "Overall_best"
;;

let print_candidate_cuttings_selection_criterion ppf = function
  | (f, u_t) ->
    Format.fprintf ppf "%,@[<1>(@,"; Lib_print.print_quoted_float ppf f;
    Format.fprintf ppf "%,,@ "; Unatural_print.print_t ppf u_t;
    Format.fprintf ppf "%,@,)@]"
;;

let print_stopping_criterion ppf = function
  | {
      Refinement_types.max_iteration = u_s;
      Refinement_types.min_best_scalar_indicator = f;
      Refinement_types.min_scalar_relative_error = f0;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Format.fprintf ppf "%,@[<1>max_iteration =@ ";
    Uhistory_types_print.print_state_number ppf u_s;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>min_best_scalar_indicator =@ ";
    Lib_print.print_quoted_float ppf f; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>min_scalar_relative_error =@ ";
    Lib_print.print_quoted_float ppf f0; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@,}@]"
;;

let print_graphics_mode ppf = function
  | Refinement_types.No_graphics -> Format.fprintf ppf "%s" "No_graphics"
  | Refinement_types.Parameter_graphics ->
    Format.fprintf ppf "%s" "Parameter_graphics"
  | Refinement_types.Full_graphics -> Format.fprintf ppf "%s" "Full_graphics"
;;

let print_output_status ppf = function
  | Refinement_types.Max_iteration u_s ->
    Format.fprintf ppf "@[<1>%s@ " "Max_iteration";
    Uhistory_types_print.print_state_number ppf u_s;
    Format.fprintf ppf "%,@]"
  | Refinement_types.Min_scalar_indicator f ->
    Format.fprintf ppf "@[<1>%s@ " "Min_scalar_indicator";
    Lib_print.print_quoted_float ppf f; Format.fprintf ppf "%,@]"
  | Refinement_types.Min_scalar_relative_error f ->
    Format.fprintf ppf "@[<1>%s@ " "Min_scalar_relative_error";
    Lib_print.print_quoted_float ppf f; Format.fprintf ppf "%,@]"
  | Refinement_types.No_more_cuttings ->
    Format.fprintf ppf "%s" "No_more_cuttings"
;;

(* End of OCamlGen, 3.3+dev4 generated code *)
